## Typing stubs for ibm-db

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`ibm-db`](https://github.com/ibmdb/python-ibmdb) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
[Pyre](https://pyre-check.org/),
PyCharm, etc. to check code that uses `ibm-db`. This version of
`types-ibm-db` aims to provide accurate annotations for
`ibm-db==3.2.5`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/ibm-db`](https://github.com/python/typeshed/tree/main/stubs/ibm-db)
directory.

This package was tested with
mypy 1.14.0,
pyright 1.1.389,
and pytype 2024.10.11.
It was generated from typeshed commit
[`2047b820730fdd65d37e6e8efcf29ca9af7ec3e7`](https://github.com/python/typeshed/commit/2047b820730fdd65d37e6e8efcf29ca9af7ec3e7).